Skein Stream Cipher — PySkein v0.7.1 documentation

### Navigation

- index
- next |
- previous |
- PySkein v0.7.1 documentation »

# Skein Stream Cipher

PySkein contains a simple stream cipher based on Skein:

    >>> import skein
    >>> sc = skein.StreamCipher(b"secret")
    >>> x = sc.encrypt(b"squeamish ossifrage")
    >>> x
    b'\x94!\xc5\xbfM\xb5%{\x96qPw\x7f\x16]\xf3\x1cEe'
    >>> sc = skein.StreamCipher(b"secret")
    >>> sc.decrypt(x)
    b'squeamish ossifrage'

### Navigation

- index
- next |
- previous |
- PySkein v0.7.1 documentation »